#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Exemple pour reconnaissance des inondations
# 
# Petit exemple appris sur très peu d'images...

# In[1]:


import os
from PIL import Image, ImageOps
import numpy as np
import matplotlib.pyplot as plt
from sklearn.model_selection import train_test_split
from sklearn.svm import SVC
from sklearn.model_selection import cross_val_score
from sklearn.metrics import confusion_matrix


# # Chargement des images

# In[2]:


images = []
target = []
for repo in os.listdir("sample_labelled_train"):
    if repo.endswith("1"):
        target_ = 1
    else:
        target_= 0
    
    for image in os.listdir(os.path.join("sample_labelled_train", repo)):
        file_name = os.path.join("sample_labelled_train", repo, image)
        images.append(Image.open(file_name))
        target.append(target_)


# # Recadrage des images en 224x224 

# In[3]:


array_images = np.zeros((len(images), 224, 224, 3))

for _, image in enumerate(images):
    array_image = np.array(image)
    image_ = np.zeros((224, 224, 3))
    x_win = max(array_image.shape[0]//224, 1)
    y_win = max(array_image.shape[1]//224, 1)
    for x in range(224):
        for y in range(224):
            for z in range(3):
                if x*x_win < array_image.shape[0] and y*y_win < array_image.shape[1]:
                    image_[x, y, z] = int(np.max(array_image[x*x_win: (x+1)*x_win, y*y_win: (y+1)*y_win, z]))
                
    array_images[_, :, :, :] = image_


# In[4]:


for _ in np.random.choice([i for i in range(len(images))], 10):
    plt.imshow(array_images[_,:,:,:].astype('int'))
    plt.show()


# # Import de modèles pré-entrainés

# In[5]:


import keras
from keras.applications import vgg16, inception_v3, resnet50, mobilenet
#Load the VGG model
vgg_model = vgg16.VGG16(weights='imagenet')
 
#Load the Inception_V3 model
inception_model = inception_v3.InceptionV3(weights='imagenet')
 
#Load the ResNet50 model
resnet_model = resnet50.ResNet50(weights='imagenet')
 
#Load the MobileNet model
mobilenet_model = mobilenet.MobileNet(weights='imagenet')


# In[6]:


vgg_model.summary()


# In[7]:


inception_model.summary()


# In[8]:


resnet_model.summary()


# In[9]:


mobilenet_model.summary()


# #  Utilisation des caractéristiques extraites par le modèle Vgg16 comme input pour un SVM

# In[10]:


from keras.models import Model

intermediate_layer_model = Model(inputs=vgg_model.input,
                                 outputs=vgg_model.layers[-3].output)
intermediate_output = intermediate_layer_model.predict(array_images)


# In[11]:


X_train, X_test, y_train, y_test = train_test_split(intermediate_output, target)


# In[12]:


clf = SVC(gamma='auto', kernel='linear')
clf.fit(X_train, y_train)


# In[13]:


scores = []
for d in range(1, 5):
    clf = SVC(gamma='auto', kernel='poly', degree=d)
    scores_ = cross_val_score(clf, intermediate_output, target, cv=3, scoring='accuracy')
    scores.append(np.mean(scores_))


# In[14]:


scores


# In[15]:


scores = []
for d in range(1, 5):
    clf = SVC(gamma='auto', kernel='poly', degree=d)
    scores_ = cross_val_score(clf, intermediate_output, target, cv=3, scoring='roc_auc')
    scores.append(np.mean(scores_))


# In[16]:


scores


# In[17]:


clf = SVC(gamma='auto', kernel='poly', degree=1)
clf.fit(X_train, y_train)
confusion_matrix(clf.predict(X_test), y_test)


# In[18]: